#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 djot
version:              0.1.2.3
visibility:           public
id:                   djot-0.1.2.3-AKfz0ISSQKx7buYmpeZBEt
key:                  djot-0.1.2.3-AKfz0ISSQKx7buYmpeZBEt
license:              MIT
copyright:            Copyright (C) 2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parser and renderer for djot light markup syntax.
description:
    Djot (<https://djot.net>) is a light markup language.
    This package provides a data structure to represent
    djot documents, a very fast parser, and functions
    to render a parsed document as HTML and as djot.

category:             Text
abi:                  3610dbd3156d956629f2465de5199fba
exposed:              True
exposed-modules:
    Djot Djot.AST Djot.Attributes Djot.Blocks Djot.Djot Djot.Html
    Djot.Inlines Djot.Options Djot.Parse

import-dirs:          /usr/lib/ghc-9.6.6/site-local/djot-0.1.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/djot-0.1.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/djot-0.1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-djot
hs-libraries:         HSdjot-0.1.2.3-AKfz0ISSQKx7buYmpeZBEt
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    doclayout-0.5.0.1-I6PZeVKNTgQHHgfWxGlKVN mtl-2.3.1
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-djot/html/djot.haddock
haddock-html:         /usr/share/doc/haskell-djot/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

